
#ARNICA: an Open Source Python module as a toolkit for CFD

In Arnica, useful features related to Computational Fluid Dynamics (CFD) are implemented, namely:

  1. *CFD related tools* aiming to be used together with the Reactive software suite [AVBP](http://www.cerfacs.fr/avbp7x/)
  2. *CFD related bare functionnalities* such as ParaView-readable XDMF writers from Numpy arrays, axi-symetric shell generators, 2D finite differences solvers, _etc._
  
Contributors are, for the moment, the CERFACS/[COOP Team](http://cerfacs.fr/coop/team/) that can be reached at [coop@cerfacs.fr](coop@cerfacs.fr).

If you are willing to contribute, please read carefully the guide in the `CONTRIBUTING.md` file.

# Installation

Arnica can be installed directly in your Python 3 environnement by running the command:

```
pip install arnica
```

This command will install Arnica and all its dependencies (if needed). Once this step is over you can use arnica as a Python module in a script:

```python
import arnica
```

# License

CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
